@@ -45,15 +45,11 @@ class Config
      */
     public function supportedSessionExpiry(): array
     {
-        return array_values(
-            array_unique(
-                array_merge(
-                    [
-                        $this->requireString('sessionExpiry', self::SESSION_EXPIRY_DEFAULT),
-                    ],
-                    $this->requireStringArray('supportedSessionExpiry', [])
-                )
-            )
+        return array_merge(
+            [
+                $this->requireString('sessionExpiry', self::SESSION_EXPIRY_DEFAULT),
+            ],
+            $this->requireStringArray('supportedSessionExpiry', [])
         );
     }
 
@@ -173,7 +169,7 @@ class Config
             }
         }
 
-        throw new ConfigException('profile "'.$profileId.'" does not exist');
+        throw new ConfigException('profile "' . $profileId . '" does not exist');
     }
 
     /**
@@ -256,6 +252,18 @@ class Config
         return new LdapAuthConfig($this->s('LdapAuthModule')->toArray());
     }
 
+    public function staticPermissionsConfig(string $baseDir): StaticPermissionsConfig
+    {
+        return new StaticPermissionsConfig(
+            array_merge(
+                [
+                    'baseDir' => $baseDir,
+                ],
+                $this->s('StaticPermissions')->toArray()
+            )
+        );
+    }
+
     /**
      * @psalm-suppress UnresolvableInclude
      */
@@ -305,6 +313,7 @@ class Config
             'supportedSessionExpiry',
             'vpnCaPath',
             'WireGuard',
+            'StaticPermissions',
         ];
 
         $unsupportedKeys = [];
