@@ -13,6 +13,4 @@ namespace Vpn\Portal\Crypto\Exception;
 
 use Exception;
 
-class CryptoException extends Exception
-{
-}
+class CryptoException extends Exception {}
