@@ -21,4 +21,9 @@ class Hex
     {
         return sodium_bin2hex($string);
     }
+
+    public static function decode(string $string): string
+    {
+        return sodium_hex2bin($string);
+    }
 }
