@@ -9,7 +9,7 @@ declare(strict_types=1);
  * SPDX-License-Identifier: AGPL-3.0+
  */
 
-require_once dirname(__DIR__).'/vendor/autoload.php';
+require_once dirname(__DIR__) . '/vendor/autoload.php';
 $baseDir = dirname(__DIR__);
 
 use fkooman\OAuth\Server\BearerValidator;
@@ -21,6 +21,7 @@ use Vpn\Portal\ConnectionHooks;
 use Vpn\Portal\ConnectionManager;
 use Vpn\Portal\FileIO;
 use Vpn\Portal\Http\ApiService;
+use Vpn\Portal\Http\Auth\LdapCredentialValidator;
 use Vpn\Portal\Http\GuestApiService;
 use Vpn\Portal\Http\JsonResponse;
 use Vpn\Portal\Http\Request;
@@ -30,8 +31,10 @@ use Vpn\Portal\OAuth\NullAccessTokenVerifier;
 use Vpn\Portal\OAuth\VpnClientDb;
 use Vpn\Portal\OpenVpn\CA\VpnCa;
 use Vpn\Portal\OpenVpn\TlsCrypt;
+use Vpn\Portal\PermissionSourceManager;
 use Vpn\Portal\ServerInfo;
 use Vpn\Portal\ServerList;
+use Vpn\Portal\StaticPermissionsSource;
 use Vpn\Portal\Storage;
 use Vpn\Portal\SysLogger;
 use Vpn\Portal\VpnDaemon;
@@ -43,17 +46,17 @@ $logger = new SysLogger('vpn-user-portal');
 
 try {
     $request = Request::createFromGlobals();
-    FileIO::mkdir($baseDir.'/data');
-    $config = Config::fromFile($baseDir.'/config/config.php');
+    FileIO::mkdir($baseDir . '/data');
+    $config = Config::fromFile($baseDir . '/config/config.php');
     $storage = new Storage($config->dbConfig($baseDir));
     $oauthStorage = new OAuthStorage($storage->dbPdo(), 'oauth_');
-    $ca = new VpnCa($baseDir.'/config/keys/ca', $config->vpnCaPath());
-    $oauthKey = FileIO::read($baseDir.'/config/keys/oauth.key');
+    $ca = new VpnCa($baseDir . '/config/keys/ca', $config->vpnCaPath());
+    $oauthKey = FileIO::read($baseDir . '/config/keys/oauth.key');
 
     [,,$localKeyId] = explode('.', $oauthKey, 4);
 
     if ($config->apiConfig()->enableGuestAccess()) {
-        $serverList = new ServerList($baseDir.'/data', $config->apiConfig());
+        $serverList = new ServerList($baseDir . '/data', $config->apiConfig());
         $bearerValidator = new BearerValidator(
             new Signer($oauthKey, $serverList),
             new NullAccessTokenVerifier()
@@ -63,7 +66,7 @@ try {
         $bearerValidator = new BearerValidator(
             new Signer($oauthKey),
             new LocalAccessTokenVerifier(
-                new VpnClientDb($baseDir.'/config/oauth_client_db.json'),
+                new VpnClientDb($baseDir . '/config/oauth_client_db.json', $config->apiConfig()->appSets()),
                 $oauthStorage
             )
         );
@@ -72,14 +75,22 @@ try {
 
     $serverInfo = new ServerInfo(
         $request->getRootUri(),
-        $baseDir.'/data/keys',
+        $baseDir . '/data/keys',
         $ca,
-        new TlsCrypt($baseDir.'/data/keys'),
+        new TlsCrypt($baseDir . '/data/keys'),
         $config->wireGuardConfig(),
         Signer::publicKeyFromSecretKey($oauthKey)
     );
 
-    $connectionManager = new ConnectionManager($config, new VpnDaemon(new CurlHttpClient($baseDir.'/config/keys/vpn-daemon'), $logger), $storage, ConnectionHooks::init($config, $storage, $logger), $logger);
+    $permissionSourceManager = new PermissionSourceManager();
+    if ($config->staticPermissionsConfig($baseDir)->isLivePermissionSource()) {
+        $permissionSourceManager->add(new StaticPermissionsSource($config->staticPermissionsConfig($baseDir), $request));
+    }
+    if ($config->ldapAuthConfig()->isLivePermissionSource()) {
+        $permissionSourceManager->add(new LdapCredentialValidator($config->ldapAuthConfig()));
+    }
+
+    $connectionManager = new ConnectionManager($config, new VpnDaemon(new CurlHttpClient($baseDir . '/config/keys/vpn-daemon'), $logger), $storage, ConnectionHooks::init($config, $storage, $logger), $logger);
 
     $service->addModule(
         new VpnApiThreeModule(
@@ -87,7 +98,8 @@ try {
             $storage,
             $oauthStorage,
             $serverInfo,
-            $connectionManager
+            $connectionManager,
+            $permissionSourceManager
         )
     );
 
